@@ -594,7 +594,7 @@ static void do_kill_fd(struct resource *r)
 }
 
 /* Initializes a file structure, and adds it to the backend's list. */
-static void init_file(struct io_backend *b, struct nonblocking_fd *f, int fd)
+void init_file(struct io_backend *b, struct nonblocking_fd *f, int fd)
 {
 	/* assert(fd); */
 	f->fd = fd;
